#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const meow = require("meow");
const _1 = require(".");
const cli = meow(`
Usage: 
  $ graphql-playground-mock FILE_PATH

GraphQL Playground Server mocks givin GraphQL Schema file(File must be GraphQL SDL syntax) at http://localhost:4000 (by default)

Options:
  --port, -p      Output in JSON format (based on introspection query)
`, {
    flags: {
        port: {
            type: 'number',
            alias: 'p',
        },
    },
});
const defaultPort = 4000;
const getPortFromInput = (cli) => {
    if (Number.isNaN(cli.flags.port) || typeof cli.flags.port === 'undefined') {
        return defaultPort;
    }
    else {
        return cli.flags.port;
    }
};
const main = (cli) => {
    const [filepath] = cli.input;
    if (!filepath) {
        console.warn('No filepath provided');
        return;
    }
    const port = getPortFromInput(cli);
    _1.server(filepath).listen(port).then(({ url }) => {
        console.log(`🚀 GraphQL Mock Server is ready at ${url}`);
    });
};
if (process.env.NODE_ENV !== 'test')
    main(cli);
//# sourceMappingURL=bin.js.map